==> jena-5.0.0-rc1-source-release.zip: jena-5.0.0-rc1/jena-arq/src/test/java/org/apache/jena/riot/lang/rdfxml/rrx/Test_RRX_Local_SAX.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.riot.lang.rdfxml.rrx;

import java.util.List;

import org.apache.jena.riot.ReaderRIOTFactory;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;

/**
 * Local basic testing to make sure the general parsing is OK in addition to running the W3C Test Suite.
 *
 * These test assume that ARP is correct!
 */
@RunWith(Parameterized.class)
public class Test_RRX_Local_SAX extends AbstractTestRDFXML_RRX {

    private static ReaderRIOTFactory rdfxmlSAXfactory = ReaderRDFXML_SAX.factory;
    private static String implLabel = "SAX";

    @Parameters(name = "{index}: {0} {1}")
    public static Iterable<Object[]> data() {
        List<String> testfiles = RunTestRDFXML.localTestFiles();
        return RunTestRDFXML.makeTestSetup(testfiles, implLabel);
    }

    public Test_RRX_Local_SAX(String label, String filename) {
        super(label, rdfxmlSAXfactory, implLabel, filename);
    }
}

==> jena-5.6.0-source-release.zip: jena-5.6.0/jena-arq/src/test/java/org/apache/jena/riot/lang/rdfxml/rrx/Test_RRX_Local_SAX.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.riot.lang.rdfxml.rrx;

import java.util.List;
import java.util.stream.Stream;

import org.junit.jupiter.params.ParameterizedClass;
import org.junit.jupiter.params.provider.MethodSource;

import org.apache.jena.riot.ReaderRIOTFactory;

/**
 * Local basic testing to make sure the general parsing is OK in addition to running the W3C Test Suite.
 */
@ParameterizedClass
@MethodSource("provideArgs")
public class Test_RRX_Local_SAX extends AbstractTestRDFXML_RRX {

    private static ReaderRIOTFactory rdfxmlSAXfactory = ReaderRDFXML_SAX.factory;
    private static String implLabel = "SAX";

    private static Stream<RRX_TestFileArgs> provideArgs() {
        List<String> testfiles = RunTestRDFXML.localTestFiles();
        return RunTestRDFXML.makeTestSetup(implLabel, rdfxmlSAXfactory, testfiles).stream();
    }

    public Test_RRX_Local_SAX(RRX_TestFileArgs args) {
        super(args, implLabel);
    }
}
